@@ -23,19 +23,27 @@
  *            Old Forge, PA 18518
  */
  
+#include <varconf/Config.h>
+
 #include <cstdio>
 #include <iostream>
 #include <fstream>
 #include <string>
 
-#include "varconf/Config.h"
-
 #ifdef __WIN32__
 #include <tchar.h>
 #define snprintf _snprintf
 #endif
 
-extern char **environ;
+extern char** environ;
+
+// on OS-X, the CRT doesn't expose the environ symbol. The following
+// code (found on Google) provides a value to link against, and a
+// further tweak in getEnv gets the actual value using _NS evil.
+#if defined(__APPLE__)
+    #include <crt_externs.h>
+    char **environ = NULL;
+#endif
 
 using namespace SigC;
 
@@ -168,16 +176,26 @@ bool Config::erase( const std::string& section, const std::string& key)
 
 bool Config::find( const std::string& section, const std::string& key)
 {
-  if ( m_conf.count( section)) {
-    if ( key == "") 
+  conf_map::const_iterator I = m_conf.find(section);
+  if (I != m_conf.end()) {
+    if ( key == "") {
       return true;
-    else if ( m_conf[section].count( key))
+    } 
+    const sec_map & sectionRef = I->second;
+    sec_map::const_iterator J = sectionRef.find(key);
+    if (J != sectionRef.end()) {
       return true;
+    }
   }
 
   return false;
 }
 
+bool Config::findSection( const std::string& section)
+{
+  return find( section);
+}
+
 bool Config::findItem( const std::string& section, const std::string& key)
 {
   return find( section, key);
@@ -189,7 +207,7 @@ void Config::getCmdline( int argc, char** argv)
   bool fnd_sec = false, fnd_nam = false;
   size_t mark = 2;
 
-  for ( size_t i = 1; i < argc; i++) {
+  for ( size_t i = 1; i < (size_t)argc; i++) {
     if ( argv[i][0] == '-' && argv[i][1] == '-' && argv[i][2] != '\0') {
       arg = argv[i];
       fnd_sec = fnd_nam = false;
@@ -254,6 +272,11 @@ void Config::getEnv( const std::string& prefix)
   std::string name = "", value = "", section = "", env = "";
   size_t eq_pos = 0;
 
+#if defined(__APPLE__)
+  if (environ == NULL)
+      environ = *_NSGetEnviron();
+#endif
+  
   for ( size_t i = 0; environ[i] != NULL; i++) {
     env = environ[i];
 
@@ -274,6 +297,11 @@ void Config::getEnv( const std::string& prefix)
   }
 }
 
+const sec_map & Config::getSection(const std::string & section)
+{
+  return m_conf[section];
+}
+
 Variable Config::getItem( const std::string& section, const std::string& key)
 {
   return ( m_conf[section])[key];
