@@ -23,13 +23,23 @@
  *            Old Forge, PA 18518
  */
  
+#include <varconf/variable.h>
+
 #include <string>
 #include <cstdio>
-#include <varconf/variable.h>
 
 #ifdef __WIN32__
 #include <tchar.h>
 #define snprintf _snprintf
+// apparently, win32 atof() is somewhat broken
+static double
+win32_atof_substitute(const char* in)
+{
+  double out;
+  sscanf(in, "%lf", &out);
+  return out;
+}
+#define atof win32_atof_substitute
 #endif  
 
 namespace varconf {
@@ -199,7 +209,7 @@ VarBase::operator double()
   return m_val_double;
 }
 
-VarBase::operator std::string()
+VarBase::operator std::string() const
 {
   return m_val;
 }
@@ -322,7 +332,7 @@ Variable& Variable::operator[](const int i)
     VarPtr::operator=(new_array);
     the_array = new_array;
   }
-  else if (the_array->size() < i + 1)
+  else if ((int)the_array->size() < i + 1)
     the_array->resize(i + 1);
 
   return (*the_array)[i];
